==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/grph2/ulpack/ulxlog.c <==
/* src/grph2/ulpack/ulxlog.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static real c_b13 = 1.f;
static logical c_true = TRUE_;
static integer c__10 = 10;
static integer c__1 = 1;
static real c_b28 = 10.f;
static integer c__4 = 4;
static integer c__2 = 2;
static integer c__16 = 16;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int ulxlog_(char *cside, integer *nlbl, integer *nticks, 
	ftnlen cside_len)
{
    /* System generated locals */
    address a__1[4], a__2[2];
    integer i__1, i__2, i__3, i__4[4], i__5[2];
    real r__1, r__2;
    char ch__1[1], ch__2[1], ch__3[7];
    icilist ici__1;

    /* Builtin functions */
    double r_sign(real *, real *), pow_ri(real *, integer *);
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
	     char **, integer *, integer *, ftnlen);

    /* Local variables */
    static char ch[16*50];
    static integer ib;
    static real bl[10];
    static integer nb;
    static real bs[10];
    static integer ip;
    static real ux1[200], ux2[50];
    static integer nbl;
    static char chr[8], chw[16];
    static integer nbs, nbt;
    static real sgn, uxt[50], xxx;
    extern /* Subroutine */ int gnge_(real *, real *, integer *);
    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
    static logical loff;
    extern /* Subroutine */ int gnle_(real *, real *, integer *);
    static char cfmt[16];
    extern logical lrgt_(real *, real *);
    extern integer lenz_(char *, ftnlen);
    static real xmin;
    extern logical lrlt_(real *, real *);
    static real xmax;
    static integer isup, irst;
    extern /* Subroutine */ int cladj_(char *, ftnlen);
    static logical label;
    extern /* Subroutine */ int chval_(char *, real *, char *, ftnlen, ftnlen)
	    ;
    static logical lcntl;
    static integer ixchr, ipmax;
    static logical lepsl;
    static real bxmax, bxmin;
    static integer ipmin, itype;
    extern /* Subroutine */ int vrgnn_(real *, integer *, integer *);
    static integer jtype;
    static real uxmin, uymin, uxmax, uymax, factor;
    extern /* Subroutine */ int gllget_(char *, logical *, ftnlen), gnsblk_(
	    real *, integer *), sgiget_(char *, integer *, ftnlen), gnsave_(
	    void), sglget_(char *, logical *, ftnlen), msgdmp_(char *, char *,
	     char *, ftnlen, ftnlen, ftnlen), uliget_(char *, integer *, 
	    ftnlen), gllset_(char *, logical *, ftnlen);
    extern logical luxchk_(char *, ftnlen);
    extern /* Subroutine */ int uzcget_(char *, char *, ftnlen, ftnlen), 
	    ulxlbl_(real *, integer *, integer *), sgqwnd_(real *, real *, 
	    real *, real *), gnrset_(void), sgswnd_(real *, real *, real *, 
	    real *), uxplbl_(char *, integer *, real *, char *, integer *, 
	    integer *, ftnlen, ftnlen), sgstrf_(void), uzlget_(char *, 
	    logical *, ftnlen), uzrget_(char *, real *, ftnlen), uxpaxs_(char 
	    *, integer *, ftnlen), uxptmk_(char *, integer *, real *, integer 
	    *, ftnlen);

    /* Fortran I/O blocks */
    static icilist io___35 = { 0, chr, 0, "(I8)", 8, 1 };


/*     CSIDE : 'T','B','U' */
/*     NLBL  : 1-4          ... Label buffer number used in the axis */
/*     NTICKS: 1-9          ... Number of small ticks in 10**N-10**(N+1) */
    if (! luxchk_(cside, (ftnlen)1)) {
	msgdmp_("E", "ULXLOG", "INVALID CSIDE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)14);
    }
    if (*nlbl < 1 || *nlbl > 4) {
	msgdmp_("E", "ULXLOG", "INVALID NLBL.", (ftnlen)1, (ftnlen)6, (ftnlen)
		13);
    }
    if (*nticks < 1 || *nticks > 9) {
	msgdmp_("E", "ULXLOG", "INVALID NTICKS.", (ftnlen)1, (ftnlen)6, (
		ftnlen)15);
    }
    sgqwnd_(&uxmin, &uxmax, &uymin, &uymax);
    uzlget_("LOFFSET", &loff, (ftnlen)7);
    if (loff) {
	uzrget_("XFACT", &factor, (ftnlen)5);
	xmin = uxmin / factor;
	xmax = uxmax / factor;
	sgswnd_(&xmin, &xmax, &uymin, &uymax);
	sgstrf_();
    } else {
	xmin = uxmin;
	xmax = uxmax;
    }
    sgn = r_sign(&c_b13, &xmin);
    if (sgn * xmin > sgn * xmax) {
	xxx = xmin;
	xmin = xmax;
	xmax = xxx;
    }
    uliget_("IXTYPE", &itype, (ftnlen)6);
    uliget_("IXCHR", &ixchr, (ftnlen)5);
    ulxlbl_(bl, &nb, nlbl);
    sgiget_("ISUP", &isup, (ftnlen)4);
    sgiget_("IRST", &irst, (ftnlen)4);
    gllget_("LEPSL", &lepsl, (ftnlen)5);
    sglget_("LCNTL", &lcntl, (ftnlen)5);
    gllset_("LEPSL", &c_true, (ftnlen)5);
    gnsave_();
/*     SMALL TICKS */
    vrgnn_(bs, &c__10, &c__1);
    bs[*nticks] = 10.f;
    i__1 = *nticks + 1;
    gnsblk_(bs, &i__1);
    r__1 = dabs(xmax);
    gnle_(&r__1, &bxmax, &ipmax);
    r__1 = dabs(xmin);
    gnge_(&r__1, &bxmin, &ipmin);
    nbs = 0;
    i__1 = ipmax;
    for (ip = ipmin; ip <= i__1; ++ip) {
	i__2 = *nticks;
	for (ib = 1; ib <= i__2; ++ib) {
	    if (ip == ipmin && lrlt_(&bs[ib - 1], &bxmin)) {
		goto L100;
	    }
	    if (ip == ipmax && lrgt_(&bs[ib - 1], &bxmax)) {
		goto L100;
	    }
	    ++nbs;
	    if (nbs > 200) {
		msgdmp_("E", "ULXLOG", "TOO MANY TICKS.", (ftnlen)1, (ftnlen)
			6, (ftnlen)15);
	    }
	    ux1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b28, &ip);
L100:
	    ;
	}
    }
/*     LARGE LABELS AND TICKS */
    i__2 = nb + 1;
    gnsblk_(bl, &i__2);
    r__1 = dabs(xmax);
    gnle_(&r__1, &bxmax, &ipmax);
    r__1 = dabs(xmin);
    gnge_(&r__1, &bxmin, &ipmin);
    nbl = 0;
    nbt = 0;
    jtype = itype % 2;
    i__2 = ipmax;
    for (ip = ipmin; ip <= i__2; ++ip) {
	i__1 = nb;
	for (ib = 1; ib <= i__1; ++ib) {
	    if (ip == ipmin && lrlt_(&bl[ib - 1], &bxmin)) {
		goto L201;
	    }
	    if (ip == ipmax && lrgt_(&bl[ib - 1], &bxmax)) {
		goto L201;
	    }
	    if (ib == 1) {
		++nbt;
		uxt[nbt - 1] = sgn * pow_ri(&c_b28, &ip);
	    }
	    ++nbl;
	    if (nbl > 50) {
		msgdmp_("E", "ULXLOG", "TOO MANY LABELS.", (ftnlen)1, (ftnlen)
			6, (ftnlen)16);
	    }
	    ux2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b28, &ip);
	    if (itype <= 2) {
		if (jtype == 0 && ib != 1) {
		    ici__1.icierr = 0;
		    ici__1.icirnum = 1;
		    ici__1.icirlen = 16;
		    ici__1.iciunit = ch + (nbl - 1 << 4);
		    ici__1.icifmt = "(I1)";
		    s_wsfi(&ici__1);
		    i__3 = (integer) bl[ib - 1];
		    do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
		    e_wsfi();
		} else {
		    if (jtype == 1 && nb != 1) {
			ici__1.icierr = 0;
			ici__1.icirnum = 1;
			ici__1.icirlen = 16;
			ici__1.iciunit = ch + (nbl - 1 << 4);
			ici__1.icifmt = "(I1,A1)";
			s_wsfi(&ici__1);
			i__3 = (integer) bl[ib - 1];
			do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
			csgi_(ch__2, (ftnlen)1, &ixchr);
			*(unsigned char *)&ch__1[0] = *(unsigned char *)&
				ch__2[0];
			do_fio(&c__1, ch__1, (ftnlen)1);
			e_wsfi();
		    } else {
			s_copy(ch + (nbl - 1 << 4), " ", (ftnlen)16, (ftnlen)
				1);
		    }
		    s_wsfi(&io___35);
		    do_fio(&c__1, (char *)&ip, (ftnlen)sizeof(integer));
		    e_wsfi();
		    cladj_(chr, (ftnlen)8);
		    if (lcntl) {
/* Writing concatenation */
			i__4[0] = 2, a__1[0] = "10";
			csgi_(ch__1, (ftnlen)1, &isup);
			i__4[1] = 1, a__1[1] = ch__1;
			i__4[2] = lenz_(chr, (ftnlen)8), a__1[2] = chr;
			csgi_(ch__2, (ftnlen)1, &irst);
			i__4[3] = 1, a__1[3] = ch__2;
			s_cat(ch + ((nbl - 1 << 4) + 2), a__1, i__4, &c__4, (
				ftnlen)14);
		    } else {
/* Writing concatenation */
			i__5[0] = 1, a__2[0] = "E";
			i__5[1] = 8, a__2[1] = chr;
			s_cat(ch + ((nbl - 1 << 4) + 1), a__2, i__5, &c__2, (
				ftnlen)15);
		    }
		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
		}
	    } else {
		if (jtype == 0 && ib != 1) {
		    ici__1.icierr = 0;
		    ici__1.icirnum = 1;
		    ici__1.icirlen = 16;
		    ici__1.iciunit = ch + (nbl - 1 << 4);
		    ici__1.icifmt = "(I1)";
		    s_wsfi(&ici__1);
		    i__3 = (integer) bl[ib - 1];
		    do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
		    e_wsfi();
		} else {
		    uzcget_("CXFMT", cfmt, (ftnlen)5, (ftnlen)16);
		    r__2 = (r__1 = ux2[nbl - 1], dabs(r__1));
		    chval_(cfmt, &r__2, ch + (nbl - 1 << 4), (ftnlen)16, (
			    ftnlen)16);
		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
		}
	    }
L201:
	    ;
	}
    }
    if (sgn < 0.f) {
	i__1 = nbl;
	for (ib = 1; ib <= i__1; ++ib) {
/* Writing concatenation */
	    i__5[0] = 1, a__2[0] = "-";
	    i__5[1] = 16, a__2[1] = ch + (ib - 1 << 4);
	    s_cat(chw, a__2, i__5, &c__2, (ftnlen)16);
	    s_copy(ch + (ib - 1 << 4), chw, (ftnlen)16, (ftnlen)16);
/* L301: */
	}
    }
/*     DRAW AXIS, TICKS, AND LABELS */
    uxpaxs_(cside, &c__2, (ftnlen)1);
    if (nbs != 0) {
	uxptmk_(cside, &c__1, ux1, &nbs, (ftnlen)1);
    }
    if (nbt != 0) {
	uxptmk_(cside, &c__2, uxt, &nbt, (ftnlen)1);
    }
/* Writing concatenation */
    i__5[0] = 6, a__2[0] = "LABELX";
    i__5[1] = 1, a__2[1] = cside;
    s_cat(ch__3, a__2, i__5, &c__2, (ftnlen)7);
    uzlget_(ch__3, &label, (ftnlen)7);
    if (label) {
	uxplbl_(cside, &c__1, ux2, ch, &c__16, &nbl, (ftnlen)1, (ftnlen)16);
    }
    gllset_("LEPSL", &lepsl, (ftnlen)5);
    gnrset_();
    if (loff) {
	sgswnd_(&uxmin, &uxmax, &uymin, &uymax);
	sgstrf_();
    }
    return 0;
} /* ulxlog_ */

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/grph2/ulpack/ulxlog.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static real c_b13 = 1.f;
static logical c_true = TRUE_;
static integer c__10 = 10;
static integer c__1 = 1;
static real c_b28 = 10.f;
static integer c__4 = 4;
static integer c__2 = 2;
static integer c__16 = 16;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int ulxlog_(char *cside, integer *nlbl, integer *nticks, 
	ftnlen cside_len)
{
    /* System generated locals */
    address a__1[4], a__2[2];
    integer i__1, i__2, i__3, i__4[4], i__5[2];
    real r__1, r__2;
    char ch__1[1], ch__2[1], ch__3[7];
    icilist ici__1;

    /* Builtin functions */
    double r_sign(real *, real *), pow_ri(real *, integer *);
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
	     char **, integer *, integer *, ftnlen);

    /* Local variables */
    static char ch[16*50];
    static integer ib;
    static real bl[10];
    static integer nb;
    static real bs[10];
    static integer ip;
    static real ux1[200], ux2[50];
    static integer nbl;
    static char chr[8], chw[16];
    static integer nbs, nbt;
    static real sgn, uxt[50], xxx;
    extern /* Subroutine */ int gnge_(real *, real *, integer *);
    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
    static logical loff;
    extern /* Subroutine */ int gnle_(real *, real *, integer *);
    static char cfmt[16];
    extern logical lrgt_(real *, real *);
    extern integer lenz_(char *, ftnlen);
    static real xmin;
    extern logical lrlt_(real *, real *);
    static real xmax;
    static integer isup, irst;
    extern /* Subroutine */ int cladj_(char *, ftnlen);
    static logical label;
    extern /* Subroutine */ int chval_(char *, real *, char *, ftnlen, ftnlen)
	    ;
    static logical lcntl;
    static integer ixchr, ipmax;
    static logical lepsl;
    static real bxmax, bxmin;
    static integer ipmin, itype;
    extern /* Subroutine */ int vrgnn_(real *, integer *, integer *);
    static integer jtype;
    static real uxmin, uymin, uxmax, uymax, factor;
    extern /* Subroutine */ int gllget_(char *, logical *, ftnlen), gnsblk_(
	    real *, integer *), sgiget_(char *, integer *, ftnlen), gnsave_(
	    void), sglget_(char *, logical *, ftnlen), msgdmp_(char *, char *,
	     char *, ftnlen, ftnlen, ftnlen), uliget_(char *, integer *, 
	    ftnlen), gllset_(char *, logical *, ftnlen);
    extern logical luxchk_(char *, ftnlen);
    extern /* Subroutine */ int uzcget_(char *, char *, ftnlen, ftnlen), 
	    ulxlbl_(real *, integer *, integer *), sgqwnd_(real *, real *, 
	    real *, real *), gnrset_(void), sgswnd_(real *, real *, real *, 
	    real *), uxplbl_(char *, integer *, real *, char *, integer *, 
	    integer *, ftnlen, ftnlen), sgstrf_(void), uzlget_(char *, 
	    logical *, ftnlen), uzrget_(char *, real *, ftnlen), uxpaxs_(char 
	    *, integer *, ftnlen), uxptmk_(char *, integer *, real *, integer 
	    *, ftnlen);

    /* Fortran I/O blocks */
    static icilist io___35 = { 0, chr, 0, "(I8)", 8, 1 };


/*     CSIDE : 'T','B','U' */
/*     NLBL  : 1-4          ... Label buffer number used in the axis */
/*     NTICKS: 1-9          ... Number of small ticks in 10**N-10**(N+1) */
    if (! luxchk_(cside, (ftnlen)1)) {
	msgdmp_("E", "ULXLOG", "INVALID CSIDE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)14);
    }
    if (*nlbl < 1 || *nlbl > 4) {
	msgdmp_("E", "ULXLOG", "INVALID NLBL.", (ftnlen)1, (ftnlen)6, (ftnlen)
		13);
    }
    if (*nticks < 1 || *nticks > 9) {
	msgdmp_("E", "ULXLOG", "INVALID NTICKS.", (ftnlen)1, (ftnlen)6, (
		ftnlen)15);
    }
    sgqwnd_(&uxmin, &uxmax, &uymin, &uymax);
    uzlget_("LOFFSET", &loff, (ftnlen)7);
    if (loff) {
	uzrget_("XFACT", &factor, (ftnlen)5);
	xmin = uxmin / factor;
	xmax = uxmax / factor;
	sgswnd_(&xmin, &xmax, &uymin, &uymax);
	sgstrf_();
    } else {
	xmin = uxmin;
	xmax = uxmax;
    }
    sgn = r_sign(&c_b13, &xmin);
    if (sgn * xmin > sgn * xmax) {
	xxx = xmin;
	xmin = xmax;
	xmax = xxx;
    }
    uliget_("IXTYPE", &itype, (ftnlen)6);
    uliget_("IXCHR", &ixchr, (ftnlen)5);
    ulxlbl_(bl, &nb, nlbl);
    sgiget_("ISUP", &isup, (ftnlen)4);
    sgiget_("IRST", &irst, (ftnlen)4);
    gllget_("LEPSL", &lepsl, (ftnlen)5);
    sglget_("LCNTL", &lcntl, (ftnlen)5);
    gllset_("LEPSL", &c_true, (ftnlen)5);
    gnsave_();
/*     SMALL TICKS */
    vrgnn_(bs, &c__10, &c__1);
    bs[*nticks] = 10.f;
    i__1 = *nticks + 1;
    gnsblk_(bs, &i__1);
    r__1 = abs(xmax);
    gnle_(&r__1, &bxmax, &ipmax);
    r__1 = abs(xmin);
    gnge_(&r__1, &bxmin, &ipmin);
    nbs = 0;
    i__1 = ipmax;
    for (ip = ipmin; ip <= i__1; ++ip) {
	i__2 = *nticks;
	for (ib = 1; ib <= i__2; ++ib) {
	    if (ip == ipmin && lrlt_(&bs[ib - 1], &bxmin)) {
		goto L100;
	    }
	    if (ip == ipmax && lrgt_(&bs[ib - 1], &bxmax)) {
		goto L100;
	    }
	    ++nbs;
	    if (nbs > 200) {
		msgdmp_("E", "ULXLOG", "TOO MANY TICKS.", (ftnlen)1, (ftnlen)
			6, (ftnlen)15);
	    }
	    ux1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b28, &ip);
L100:
	    ;
	}
    }
/*     LARGE LABELS AND TICKS */
    i__2 = nb + 1;
    gnsblk_(bl, &i__2);
    r__1 = abs(xmax);
    gnle_(&r__1, &bxmax, &ipmax);
    r__1 = abs(xmin);
    gnge_(&r__1, &bxmin, &ipmin);
    nbl = 0;
    nbt = 0;
    jtype = itype % 2;
    i__2 = ipmax;
    for (ip = ipmin; ip <= i__2; ++ip) {
	i__1 = nb;
	for (ib = 1; ib <= i__1; ++ib) {
	    if (ip == ipmin && lrlt_(&bl[ib - 1], &bxmin)) {
		goto L201;
	    }
	    if (ip == ipmax && lrgt_(&bl[ib - 1], &bxmax)) {
		goto L201;
	    }
	    if (ib == 1) {
		++nbt;
		uxt[nbt - 1] = sgn * pow_ri(&c_b28, &ip);
	    }
	    ++nbl;
	    if (nbl > 50) {
		msgdmp_("E", "ULXLOG", "TOO MANY LABELS.", (ftnlen)1, (ftnlen)
			6, (ftnlen)16);
	    }
	    ux2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b28, &ip);
	    if (itype <= 2) {
		if (jtype == 0 && ib != 1) {
		    ici__1.icierr = 0;
		    ici__1.icirnum = 1;
		    ici__1.icirlen = 16;
		    ici__1.iciunit = ch + (nbl - 1 << 4);
		    ici__1.icifmt = "(I1)";
		    s_wsfi(&ici__1);
		    i__3 = (integer) bl[ib - 1];
		    do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
		    e_wsfi();
		} else {
		    if (jtype == 1 && nb != 1) {
			ici__1.icierr = 0;
			ici__1.icirnum = 1;
			ici__1.icirlen = 16;
			ici__1.iciunit = ch + (nbl - 1 << 4);
			ici__1.icifmt = "(I1,A1)";
			s_wsfi(&ici__1);
			i__3 = (integer) bl[ib - 1];
			do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
			csgi_(ch__2, (ftnlen)1, &ixchr);
			*(unsigned char *)&ch__1[0] = *(unsigned char *)&
				ch__2[0];
			do_fio(&c__1, ch__1, (ftnlen)1);
			e_wsfi();
		    } else {
			s_copy(ch + (nbl - 1 << 4), " ", (ftnlen)16, (ftnlen)
				1);
		    }
		    s_wsfi(&io___35);
		    do_fio(&c__1, (char *)&ip, (ftnlen)sizeof(integer));
		    e_wsfi();
		    cladj_(chr, (ftnlen)8);
		    if (lcntl) {
/* Writing concatenation */
			i__4[0] = 2, a__1[0] = "10";
			csgi_(ch__1, (ftnlen)1, &isup);
			i__4[1] = 1, a__1[1] = ch__1;
			i__4[2] = lenz_(chr, (ftnlen)8), a__1[2] = chr;
			csgi_(ch__2, (ftnlen)1, &irst);
			i__4[3] = 1, a__1[3] = ch__2;
			s_cat(ch + ((nbl - 1 << 4) + 2), a__1, i__4, &c__4, (
				ftnlen)14);
		    } else {
/* Writing concatenation */
			i__5[0] = 1, a__2[0] = "E";
			i__5[1] = 8, a__2[1] = chr;
			s_cat(ch + ((nbl - 1 << 4) + 1), a__2, i__5, &c__2, (
				ftnlen)15);
		    }
		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
		}
	    } else {
		if (jtype == 0 && ib != 1) {
		    ici__1.icierr = 0;
		    ici__1.icirnum = 1;
		    ici__1.icirlen = 16;
		    ici__1.iciunit = ch + (nbl - 1 << 4);
		    ici__1.icifmt = "(I1)";
		    s_wsfi(&ici__1);
		    i__3 = (integer) bl[ib - 1];
		    do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
		    e_wsfi();
		} else {
		    uzcget_("CXFMT", cfmt, (ftnlen)5, (ftnlen)16);
		    r__2 = (r__1 = ux2[nbl - 1], abs(r__1));
		    chval_(cfmt, &r__2, ch + (nbl - 1 << 4), (ftnlen)16, (
			    ftnlen)16);
		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
		}
	    }
L201:
	    ;
	}
    }
    if (sgn < 0.f) {
	i__1 = nbl;
	for (ib = 1; ib <= i__1; ++ib) {
/* Writing concatenation */
	    i__5[0] = 1, a__2[0] = "-";
	    i__5[1] = 16, a__2[1] = ch + (ib - 1 << 4);
	    s_cat(chw, a__2, i__5, &c__2, (ftnlen)16);
	    s_copy(ch + (ib - 1 << 4), chw, (ftnlen)16, (ftnlen)16);
/* L301: */
	}
    }
/*     DRAW AXIS, TICKS, AND LABELS */
    uxpaxs_(cside, &c__2, (ftnlen)1);
    if (nbs != 0) {
	uxptmk_(cside, &c__1, ux1, &nbs, (ftnlen)1);
    }
    if (nbt != 0) {
	uxptmk_(cside, &c__2, uxt, &nbt, (ftnlen)1);
    }
/* Writing concatenation */
    i__5[0] = 6, a__2[0] = "LABELX";
    i__5[1] = 1, a__2[1] = cside;
    s_cat(ch__3, a__2, i__5, &c__2, (ftnlen)7);
    uzlget_(ch__3, &label, (ftnlen)7);
    if (label) {
	uxplbl_(cside, &c__1, ux2, ch, &c__16, &nbl, (ftnlen)1, (ftnlen)16);
    }
    gllset_("LEPSL", &lepsl, (ftnlen)5);
    gnrset_();
    if (loff) {
	sgswnd_(&uxmin, &uxmax, &uymin, &uymax);
	sgstrf_();
    }
    return 0;
} /* ulxlog_ */
